summaryrefslogtreecommitdiffstats
path: root/src/mesa/program/programopt.c
diff options
context:
space:
mode:
authorTimothy Arceri <[email protected]>2016-10-20 14:24:03 +1100
committerTimothy Arceri <[email protected]>2016-10-26 14:29:36 +1100
commite81aaeba37f5419323d8f88bc10943c77e25ed14 (patch)
tree3dc9c65fd0984128fb559aa71ed4ae4c7493995e /src/mesa/program/programopt.c
parentdfcbdba47119de6c1d81a869f8625bcc3d7560a2 (diff)
r200/i915/st/mesa/compiler: use common inputs read field
And set set inputs_read directly in shader_info. To avoid regressions between changes this change is a squashed version of the following patches. st/mesa changes where: Reviewed-by: Marek Olšák <[email protected]> Reviewed-by: Jason Ekstrand <[email protected]>
Diffstat (limited to 'src/mesa/program/programopt.c')
-rw-r--r--src/mesa/program/programopt.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/mesa/program/programopt.c b/src/mesa/program/programopt.c
index f51005d13d5..3c9839bf248 100644
--- a/src/mesa/program/programopt.c
+++ b/src/mesa/program/programopt.c
@@ -107,7 +107,7 @@ _mesa_insert_mvp_dp4_code(struct gl_context *ctx, struct gl_program *vprog)
/* install new instructions */
vprog->Instructions = newInst;
vprog->NumInstructions = newLen;
- vprog->InputsRead |= VERT_BIT_POS;
+ vprog->info.inputs_read |= VERT_BIT_POS;
vprog->OutputsWritten |= BITFIELD64_BIT(VARYING_SLOT_POS);
}
@@ -208,7 +208,7 @@ _mesa_insert_mvp_mad_code(struct gl_context *ctx, struct gl_program *vprog)
/* install new instructions */
vprog->Instructions = newInst;
vprog->NumInstructions = newLen;
- vprog->InputsRead |= VERT_BIT_POS;
+ vprog->info.inputs_read |= VERT_BIT_POS;
vprog->OutputsWritten |= BITFIELD64_BIT(VARYING_SLOT_POS);
}
@@ -238,7 +238,7 @@ _mesa_insert_mvp_code(struct gl_context *ctx, struct gl_program *vprog)
* \param saturate True if writes to color outputs should be clamped to [0, 1]
*
* \note
* This function sets \c VARYING_BIT_FOGC in \c fprog->Base.InputsRead.
*
* \todo With a little work, this function could be adapted to add fog code
* to vertex programs too.
@@ -408,7 +408,7 @@ _mesa_append_fog_code(struct gl_context *ctx, struct gl_program *fprog,
/* install new instructions */
fprog->Instructions = newInst;
fprog->NumInstructions = inst - newInst;
- fprog->InputsRead |= VARYING_BIT_FOGC;
+ fprog->info.inputs_read |= VARYING_BIT_FOGC;
assert(fprog->OutputsWritten & (1 << FRAG_RESULT_COLOR));
}
@@ -592,10 +592,10 @@ _mesa_program_fragment_position_to_sysval(struct gl_program *prog)
GLuint i;
if (prog->Target != GL_FRAGMENT_PROGRAM_ARB ||
- !(prog->InputsRead & BITFIELD64_BIT(VARYING_SLOT_POS)))
+ !(prog->info.inputs_read & BITFIELD64_BIT(VARYING_SLOT_POS)))
return;
- prog->InputsRead &= ~BITFIELD64_BIT(VARYING_SLOT_POS);
+ prog->info.inputs_read &= ~BITFIELD64_BIT(VARYING_SLOT_POS);
prog->SystemValuesRead |= 1 << SYSTEM_VALUE_FRAG_COORD;
for (i = 0; i < prog->NumInstructions; i++) {
@@ -238,7 +238,7 @@ _mesa_insert_mvp_code(struct gl_context *ctx, struct gl_program *vprog)
*
* \note
- * This function sets \c VARYING_BIT_FOGC in \c fprog->Base.InputsRead.
+ * This function sets \c VARYING_BIT_FOGC in \c fprog->info.inputs_read.
*
* \todo With a little work, this function could be adapted to add fog code